@@ -3,7 +3,11 @@
 
 #include <QImage>
 #include <QMutex>
-#include <poppler/qt4/poppler-qt4.h>
+#if QT_VERSION >= 0x050000
+#	include <poppler-qt5.h>
+#else
+#	include <poppler-qt4.h>
+#endif
 
 
 class SelectionLine;
@@ -22,10 +26,18 @@ public:
 //	QString get_label() const;
 
 private:
+	void toggle_invert_colors();
+
 	float width;
 	float height;
 	QImage img[3];
 	QImage thumbnail;
+	// for inverted colors with reduced contrast
+	// img_other contain the currently not needed color versions
+	// img store the current versions to be displayed
+	QImage img_other[3];
+	QImage thumbnail_other;
+
 //	QString label;
 	QList<Poppler::Link *> *links;
 	QMutex mutex;
